==> qmmp-0.8.5.tar.bz2: qmmp-0.8.5/src/plugins/Input/vorbis/translations/vorbis_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Suplemento Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="56"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ficheiros Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="132"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Sobre o suplemento Ogg Vorbis Audio</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="133"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Suplemento Qmmp Ogg Vorbis Audio</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="134"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="135"/>
        <source>Source code based on mq3 project</source>
        <translation>Baseado no código fonte do projeto mq3</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Tamanho de ficheiro</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp-0.9.10.tar.bz2: qmmp-0.9.10/src/plugins/Input/vorbis/translations/vorbis_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="52"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Suplemento Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="55"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ficheiros Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="134"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Sobre o suplemento Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="135"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Suplemento Qmmp Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="136"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="137"/>
        <source>Source code based on mq3 project</source>
        <translation>Baseado no código fonte do projeto mq3</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="58"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="60"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="61"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="61"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="62"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="62"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
